@@ -2,11 +2,10 @@ from zope import interface
 
 class IResourceLocator(interface.Interface):
     def get_path(resource):
-        """Returns an absolute path for a resource."""
+        """Returns an absolute path to a resource."""
 
 class IXapianConnection(interface.Interface):
-    """ utility to fetch thread-local xapian connections. """
+    """Utility to fetch thread-local xapian connections. """
 
     def get_connection():
-        """ return xapian connection. """
-
+        """ return xapian connection."""
