@@ -9,6 +9,9 @@ import interfaces
 class FileSystemResource(object):
     interface.implements(IIndexable)
 
+    __name__ = None
+    __parent__ = None
+    
     def __init__(self, path):
         self.path = path
 
